@@ -128,7 +128,7 @@ def setup(ctx, yes, teacher, config, debug):
     if errors:
         click.echo(error(f"{len(errors)} setup tasks failed:"))
         for task, tb in errors:
-            click.echo(error(task.descrition))
+            click.echo(error(task.description))
             if debug:
                 click.echo(debug(tb, preformatted=True))
     ctx.invoke(update)
